=======
History
=======

0.2.0 (2019-01-22)
------------------

* Add -a/--add to enable adding packages to requirement files.
* Added -d/--docs to launch docs URL in browser
* Allow version specific querying

0.1.2 (2019-01-20)
------------------

* Display more package info
* added --more/-m for even more info

0.1.1 (2019-01-02)
------------------

* First release on PyPI.
